Method: AutomateIt::PackageManager::PEAR#install
- Defined in:
- lib/automateit/package_manager/pear.rb
#install(*packages) ⇒ Object
IMPORTANT: See documentation at the top of this file for how to correctly install packages from a specific channel.
Options:
-
:force – Force installation, needed when installing unstable packages
See AutomateIt::PackageManager#install
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/automateit/package_manager/pear.rb', line 67 def install(*packages) return _install_helper(*packages) do |list, opts| # pear options: # -a install all required dependencies # -f force installation cmd = "(pear config-set auto_discover 1; " cmd << "pear install -a" cmd << " -f" if opts[:force] cmd << " "+list.join(" ")+" < /dev/null)" cmd << " > /dev/null" if opts[:quiet] cmd << " 2>&1" interpreter.sh(cmd) end end |